@@ -9,11 +9,11 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.DocDB 1.19.1\n"
-        "Version:         1.19.1.post1\n"
+        "Type annotations for boto3.DocDB 1.19.9\n"
+        "Version:         1.19.9\n"
         "Builder version: 6.0.2\n"
         "Docs:            https://pypi.org/project/mypy-boto3-docdb/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/docdb.html#DocDB\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.19.9/reference/services/docdb.html#DocDB\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
@@ -23,7 +23,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.19.1.post1")
+    print("1.19.9")
 
 
 def main() -> None:
